# eric7.Plugins.VcsPlugins.vcsGit.GitTagDialog

Module implementing a dialog to enter the data for a tagging operation.

### Global Attributes

None

### Classes

GitTagDialog | Class implementing a dialog to enter the data for a tagging operation.

### Functions

None

## GitTagDialog

Class implementing a dialog to enter the data for a tagging operation.

### Derived from

QDialog, Ui_GitTagDialog

### Class Attributes

AnnotatedTag
CreateTag
DeleteTag
LocalTag
SignedTag
VerifyTag

### Class Methods

None

### Methods

GitTagDialog | Constructor
getParameters | Public method to retrieve the tag data.
on_tagCombo_editTextChanged | Private method used to enable/disable the OK-button.

### Static Methods

None

#### GitTagDialog (Constructor)

GitTagDialog(taglist, revision=None, tagName=None, parent=None)

Constructor

taglist
  list of previously entered tags (list of strings)
revision
  revision to set tag for (string)
tagName
  name of the tag (string)
parent
  parent widget (QWidget)

#### GitTagDialog.getParameters

getParameters()

Public method to retrieve the tag data.

Return:
  tuple of two strings, two int and a boolean (tag, revision, tag operation, tag type, enforce operation)

#### GitTagDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(text)

Private method used to enable/disable the OK-button.

text
  tag name entered in the combo (string)

Up